import { Entity, Column, PrimaryGeneratedColumn, BeforeInsert, OneToMany } from 'typeorm';
import * as bcrypt from 'bcryptjs';
import * as jwt from 'jsonwebtoken';
import { MapMarkerEntity } from 'src/mapmarkers/mapmarker.entity';

@Entity('Person')
export class PersonEntity {
    @PrimaryGeneratedColumn('uuid') id: string;
    @Column({type: 'text', unique: true}) name: string;
    @Column('text') password: string;
    @OneToMany(type => MapMarkerEntity, marker => marker.player)
    markers: MapMarkerEntity[];

    @BeforeInsert()
    async hashPassword() {
        this.password = await bcrypt.hash(this.password, 10);
    }

    tokenObject() {
        const {name, token} = this;
        return {name, token};
    }

    // returns username and the id
    nameObject() {
        const {id, name} = this;
        return {id, name};
    }

    async comparePassword(attempt: string) {
        return await bcrypt.compareSync(attempt, this.password);
    }

    private get token() {
        const {id, name} = this;
        return jwt.sign({
            id, name
        },
        process.env.SECRET,
        { expiresIn: '7d'},
        );
    }
}